@@ -18,9 +18,16 @@
 
 #include <config-k3b.h>
 
-#include <kdebug.h>
+#include <QtCore/QDebug>
 
 extern "C" {
+/*
+ Recent versions of FFmepg uses C99 constant macros which are not presebt in C++ standard.
+ The macro __STDC_CONSTANT_MACROS allow C++ to use these macros. Altough it's not defined by C++ standard
+ it's supported by many implementations.
+ See bug 236036 and discussion: http://lists.mplayerhq.hu/pipermail/ffmpeg-devel/2010-May/088074.html
+ */
+#define __STDC_CONSTANT_MACROS
 #ifdef NEWFFMPEGAVCODECPATH
 #include <libavcodec/avcodec.h>
 #else
@@ -30,6 +37,7 @@ extern "C" {
 
 #include <math.h>
 
+K3B_EXPORT_PLUGIN(k3bffmpegdecoder, K3bFFMpegDecoderFactory)
 
 K3bFFMpegDecoderFactory::K3bFFMpegDecoderFactory( QObject* parent, const QVariantList& )
     : K3b::AudioDecoderFactory( parent )
@@ -48,7 +56,7 @@ K3b::AudioDecoder* K3bFFMpegDecoderFactory::createDecoder( QObject* parent ) con
 }
 
 
-bool K3bFFMpegDecoderFactory::canDecode( const KUrl& url )
+bool K3bFFMpegDecoderFactory::canDecode( const QUrl& url )
 {
     K3bFFMpegFile* file = K3bFFMpegWrapper::instance()->open( url.toLocalFile() );
     if( file ) {
